@@ -1,6 +1,8 @@
 """Code shared between the API classes."""
 import functools
 
+from ..compat import unicode_errors_default
+
 
 class Remote(object):
 
@@ -111,9 +113,9 @@ class RemoteSequence(object):
     sequences(of lines, buffers, windows and tabpages) with an API that
     is similar to the one provided by the python-vim interface.
 
-    For example, the 'buffers' property of the `Nvim class is a RemoteSequence
-    sequence instance, and the expression `nvim.buffers[0]` is translated to
-    session.request('vim_get_buffers')[0].
+    For example, the 'windows' property of the `Nvim` class is a RemoteSequence
+    sequence instance, and the expression `nvim.windows[0]` is translated to
+    session.request('vim_get_windows')[0].
 
     It can also receive an optional self_obj that will be passed as first
     argument of the request. For example, `tabpage.windows[0]` is translated
@@ -156,7 +158,7 @@ def _identity(obj, session, method, kind):
 def decode_if_bytes(obj, mode=True):
     """Decode obj if it is bytes."""
     if mode is True:
-        mode = "strict"
+        mode = unicode_errors_default
     if isinstance(obj, bytes):
         return obj.decode("utf-8", errors=mode)
     return obj
